@@ -6,15 +6,25 @@ from NEMO.models import User, Area, Resource, Interlock
 class NEMOException(Exception):
 	""" Basic NEMO exception """
 
-	default_msg = "A NEMO error occurred"
+	default_msg = "A {} error occurred"
 
 	def __init__(self, msg=None):
 		if msg is None:
-			msg = self.default_msg
+			from NEMO.views.customization import get_customization
+			site_title = get_customization('site_title')
+			msg = self.default_msg.format(site_title)
 		self.msg = msg
 		super(NEMOException, self).__init__(msg)
 
 
+class InvalidCustomizationException(NEMOException):
+	def __init__(self, name: str, value: str = None):
+		msg = f"Invalid customization ({name})"
+		if value is not None:
+			msg += f" for value: [{value}]"
+		super(InvalidCustomizationException, self).__init__(msg)
+
+
 class InterlockError(NEMOException):
 	""" Interlock related errors """
 
@@ -60,16 +70,32 @@ class NoPhysicalAccessUserError(UserAccessError):
 
 class NoAccessiblePhysicalAccessUserError(UserAccessError):
 	def __init__(self, user: User, area: Area):
+		self.area = area
 		details = f"This user is not assigned to a physical access that allow access to this area [{area}] at this time"
 		super(NoAccessiblePhysicalAccessUserError, self).__init__(user=user, msg=details)
 
 
 class UnavailableResourcesUserError(UserAccessError):
 	def __init__(self, user: User, area: Area, resources: List[Resource]):
+		self.area = area
+		self.resources = resources
 		details = f"This user was denied access to this area [{area}] because a required resource was unavailable [{resources}"
 		super(UnavailableResourcesUserError, self).__init__(user=user, msg=details)
 
 class MaximumCapacityReachedError(UserAccessError):
 	def __init__(self, user: User, area: Area):
+		self.area = area
 		details = f"This user was denied access to this area [{area}] because the area's maximum capacity of [{area.maximum_capacity}] has been reached"
 		super(MaximumCapacityReachedError, self).__init__(user=user, msg=details)
+
+class ScheduledOutageInProgressError(UserAccessError):
+	def __init__(self, user: User, area: Area):
+		self.area = area
+		details = f"This user was denied access to this area [{area}] because there is a scheduled outage in progress"
+		super(ScheduledOutageInProgressError, self).__init__(user=user, msg=details)
+
+class ReservationRequiredUserError(UserAccessError):
+	def __init__(self, user: User, area: Area):
+		self.area = area
+		details = f"This user was denied access to this area [{area}] because the user doesn't have a current reservation for that area"
+		super(ReservationRequiredUserError, self).__init__(user=user, msg=details)
