@@ -5,6 +5,7 @@ from urllib.parse import urljoin
 
 import requests
 from django.conf import settings
+from django.contrib import messages
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.auth.decorators import login_required
 from django.http import HttpResponseBadRequest
@@ -13,7 +14,8 @@ from django.utils import timezone
 from django.views.decorators.http import require_GET, require_http_methods, require_POST
 
 from NEMO.forms import UserForm, UserPreferencesForm
-from NEMO.models import User, Project, Tool, PhysicalAccessLevel, Reservation, StaffCharge, UsageEvent, AreaAccessRecord, ActivityHistory, UserPreferences, record_local_many_to_many_changes, record_active_state
+from NEMO.models import User, Project, Tool, PhysicalAccessLevel, Reservation, StaffCharge, UsageEvent, AreaAccessRecord, ActivityHistory, UserPreferences, record_local_many_to_many_changes, record_active_state, Area
+from NEMO.views.customization import get_customization
 
 users_logger = getLogger(__name__)
 
@@ -27,38 +29,51 @@ def users(request):
 @staff_member_required(login_url=None)
 @require_http_methods(['GET', 'POST'])
 def create_or_modify_user(request, user_id):
+	identity_service = get_identity_service()
+	# Get access levels and sort by area category
+	access_levels = list(PhysicalAccessLevel.objects.all().only('name', 'area'))
+	access_level_for_sort = list(set([ancestor for access in access_levels for ancestor in access.area.get_ancestors(include_self=True)]))
+	access_level_for_sort.sort(key=lambda x:x.tree_category())
+	area_access_levels = Area.objects.filter(id__in=[area.id for area in access_level_for_sort])
+	dict_area = {}
+	for access in access_levels:
+		dict_area.setdefault(access.area.id,[]).append(access)
+
 	dictionary = {
 		'projects': Project.objects.filter(active=True, account__active=True),
 		'tools': Tool.objects.filter(visible=True),
-		'physical_access_levels': PhysicalAccessLevel.objects.all(),
+		'area_access_dict': dict_area,
+		'area_access_levels': area_access_levels,
 		'one_year_from_now': timezone.now() + timedelta(days=365),
-		'identity_service_available': settings.IDENTITY_SERVICE['available'],
-		'identity_service_domains': settings.IDENTITY_SERVICE['domains'],
+		'identity_service_available': identity_service.get('available', False),
+		'identity_service_domains': identity_service.get('domains', []),
 	}
 	try:
 		user = User.objects.get(id=user_id)
 	except:
 		user = None
 
-	timeout = settings.IDENTITY_SERVICE.get('timeout', 3)
+	timeout = identity_service.get('timeout', 3)
+	site_title = get_customization('site_title')
 	if dictionary['identity_service_available']:
 		try:
-			result = requests.get(urljoin(settings.IDENTITY_SERVICE['url'], '/areas/'), timeout=timeout)
+			result = requests.get(urljoin(identity_service['url'], '/areas/'), timeout=timeout)
 			if result.status_code == HTTPStatus.OK:
 				dictionary['externally_managed_physical_access_levels'] = result.json()
 			else:
 				dictionary['identity_service_available'] = False
-				warning_message = 'The identity service encountered a problem while attempting to return a list of externally managed areas. The NEMO administrator has been notified to resolve the problem.'
+				warning_message = f"The identity service encountered a problem while attempting to return a list of externally managed areas. The administrator has been notified to resolve the problem."
 				dictionary['warning'] = warning_message
 				warning_message += ' The HTTP error was {}: {}'.format(result.status_code, result.text)
 				users_logger.error(warning_message)
 		except Exception as e:
 			dictionary['identity_service_available'] = False
-			warning_message = 'There was a problem communicating with the identity service. NEMO is unable to retrieve the list of externally managed areas. The NEMO administrator has been notified to resolve the problem.'
+			warning_message = f"There was a problem communicating with the identity service. {site_title} is unable to retrieve the list of externally managed areas. The administrator has been notified to resolve the problem."
 			dictionary['warning'] = warning_message
 			warning_message += ' An exception was encountered: ' + type(e).__name__ + ' - ' + str(e)
 			users_logger.error(warning_message)
-	else:
+	elif identity_service:
+		# display warning if identity service is defined but disabled
 		dictionary['warning'] = 'The identity service is disabled. You will not be able to modify externally managed physical access levels, reset account passwords, or unlock accounts.'
 
 	if request.method == 'GET':
@@ -69,20 +84,20 @@ def create_or_modify_user(request, user_id):
 					'username': user.username,
 					'domain': user.domain,
 				}
-				result = requests.get(settings.IDENTITY_SERVICE['url'], parameters, timeout=timeout)
+				result = requests.get(identity_service['url'], parameters, timeout=timeout)
 				if result.status_code == HTTPStatus.OK:
 					dictionary['user_identity_information'] = result.json()
 				elif result.status_code == HTTPStatus.NOT_FOUND:
 					dictionary['warning'] = "The identity service could not find username {} on the {} domain. Does the user's account reside on a different domain? If so, select that domain now and save the user information.".format(user.username, user.domain)
 				else:
 					dictionary['identity_service_available'] = False
-					warning_message = 'The identity service encountered a problem while attempting to search for a user. The NEMO administrator has been notified to resolve the problem.'
+					warning_message = 'The identity service encountered a problem while attempting to search for a user. The administrator has been notified to resolve the problem.'
 					dictionary['warning'] = warning_message
 					warning_message += ' The HTTP error was {}: {}'.format(result.status_code, result.text)
 					users_logger.error(warning_message)
 		except Exception as e:
 			dictionary['identity_service_available'] = False
-			warning_message = 'There was a problem communicating with the identity service. NEMO is unable to search for a user. The NEMO administrator has been notified to resolve the problem.'
+			warning_message = f"There was a problem communicating with the identity service. {site_title} is unable to search for a user. The administrator has been notified to resolve the problem."
 			dictionary['warning'] = warning_message
 			warning_message += ' An exception was encountered: ' + type(e).__name__ + ' - ' + str(e)
 			users_logger.error(warning_message)
@@ -104,17 +119,17 @@ def create_or_modify_user(request, user_id):
 					'domain': form.initial['domain'],
 				}
 				try:
-					result = requests.delete(settings.IDENTITY_SERVICE['url'], data=parameters, timeout=timeout)
+					result = requests.delete(identity_service['url'], data=parameters, timeout=timeout)
 					# If the delete succeeds, or the user is not found, then everything is ok.
 					if result.status_code not in (HTTPStatus.OK, HTTPStatus.NOT_FOUND):
 						dictionary['identity_service_available'] = False
 						users_logger.error('The identity service encountered a problem while attempting to delete a user. The HTTP error is {}: {}'.format(result.status_code, result.text))
-						dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+						dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The administrator has been notified to resolve the problem.'
 						return render(request, 'users/create_or_modify_user.html', dictionary)
 				except Exception as e:
 					dictionary['identity_service_available'] = False
 					users_logger.error('There was a problem communicating with the identity service while attempting to delete a user. An exception was encountered: ' + type(e).__name__ + ' - ' + str(e))
-					dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+					dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The administrator has been notified to resolve the problem.'
 					return render(request, 'users/create_or_modify_user.html', dictionary)
 
 		# Ensure the user account is added and configured correctly on the current domain if the user is active...
@@ -131,19 +146,19 @@ def create_or_modify_user(request, user_id):
 				if len(parameters['requested_areas']) > 0 and not parameters['badge_number']:
 					dictionary['warning'] = 'A user must have a badge number in order to have area access. Please enter the badge number first, then grant access to areas.'
 					return render(request, 'users/create_or_modify_user.html', dictionary)
-				result = requests.put(settings.IDENTITY_SERVICE['url'], data=parameters, timeout=timeout)
+				result = requests.put(identity_service['url'], data=parameters, timeout=timeout)
 				if result.status_code == HTTPStatus.NOT_FOUND:
 					dictionary['warning'] = 'The username was not found on this domain. Did you spell the username correctly in this form and did you select the correct domain? Ensure the user exists on the domain in order to proceed.'
 					return render(request, 'users/create_or_modify_user.html', dictionary)
 				if result.status_code != HTTPStatus.OK:
 					dictionary['identity_service_available'] = False
 					users_logger.error('The identity service encountered a problem while attempting to modify a user. The HTTP error is {}: {}'.format(result.status_code, result.text))
-					dictionary['warning'] = 'The user information was not modified because the identity service encountered a problem while creating the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+					dictionary['warning'] = 'The user information was not modified because the identity service encountered a problem while creating the corresponding domain account. The administrator has been notified to resolve the problem.'
 					return render(request, 'users/create_or_modify_user.html', dictionary)
 			except Exception as e:
 				dictionary['identity_service_available'] = False
 				users_logger.error('There was a problem communicating with the identity service while attempting to modify a user. An exception was encountered: ' + type(e).__name__ + ' - ' + str(e))
-				dictionary['warning'] = 'The user information was not modified because the identity service encountered a problem while creating the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+				dictionary['warning'] = 'The user information was not modified because the identity service encountered a problem while creating the corresponding domain account. The administrator has been notified to resolve the problem.'
 				return render(request, 'users/create_or_modify_user.html', dictionary)
 
 		# Only save the user model for now, and wait to process the many-to-many relationships.
@@ -158,6 +173,8 @@ def create_or_modify_user(request, user_id):
 		record_local_many_to_many_changes(request, user, form, 'projects')
 		form.save_m2m()
 
+		message = f"{user} has been added successfully to {site_title}" if user_id == 'new' else f"{user} has been updated successfully"
+		messages.success(request, message)
 		return redirect('users')
 	else:
 		return HttpResponseBadRequest('Invalid method')
@@ -176,22 +193,23 @@ def deactivate(request, user_id):
 	if request.method == 'GET':
 		return render(request, 'users/safe_deactivation.html', dictionary)
 	elif request.method == 'POST':
-		if settings.IDENTITY_SERVICE['available']:
+		identity_service = get_identity_service()
+		if identity_service['available']:
 			parameters = {
 				'username': user_to_deactivate.username,
 				'domain': user_to_deactivate.domain,
 			}
 			try:
-				timeout = settings.IDENTITY_SERVICE.get('timeout', 3)
-				result = requests.delete(settings.IDENTITY_SERVICE['url'], data=parameters, timeout=timeout)
+				timeout = identity_service.get('timeout', 3)
+				result = requests.delete(identity_service['url'], data=parameters, timeout=timeout)
 				# If the delete succeeds, or the user is not found, then everything is ok.
 				if result.status_code not in (HTTPStatus.OK, HTTPStatus.NOT_FOUND):
 					users_logger.error(f'The identity service encountered a problem while attempting to delete a user. The HTTP error is {result.status_code}: {result.text}')
-					dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+					dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The administrator has been notified to resolve the problem.'
 					return render(request, 'users/safe_deactivation.html', dictionary)
 			except Exception as e:
 				users_logger.error('There was a problem communicating with the identity service while attempting to delete a user. An exception was encountered: ' + type(e).__name__ + ' - ' + str(e))
-				dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The NEMO administrator has been notified to resolve the problem.'
+				dictionary['warning'] = 'The user information was not modified because the identity service could not delete the corresponding domain account. The administrator has been notified to resolve the problem.'
 				return render(request, 'users/safe_deactivation.html', dictionary)
 
 		if request.POST.get('cancel_reservations') == 'on':
@@ -243,6 +261,9 @@ def deactivate(request, user_id):
 		activity_entry.action = ActivityHistory.Action.DEACTIVATED
 		activity_entry.content_object = user_to_deactivate
 		activity_entry.save()
+
+		message = f"{user_to_deactivate} has been successfully deactivated"
+		messages.success(request, message)
 		return redirect('users')
 
 
@@ -250,9 +271,10 @@ def deactivate(request, user_id):
 @require_POST
 def reset_password(request, user_id):
 	try:
+		identity_service = get_identity_service()
 		user = get_object_or_404(User, id=user_id)
-		timeout = settings.IDENTITY_SERVICE.get('timeout', 3)
-		result = requests.post(urljoin(settings.IDENTITY_SERVICE['url'], '/reset_password/'), {'username': user.username, 'domain': user.domain}, timeout=timeout)
+		timeout = identity_service.get('timeout', 3)
+		result = requests.post(urljoin(identity_service['url'], '/reset_password/'), {'username': user.username, 'domain': user.domain}, timeout=timeout)
 		if result.status_code == HTTPStatus.OK:
 			dictionary = {
 				'title': 'Password reset',
@@ -277,9 +299,10 @@ def reset_password(request, user_id):
 @require_POST
 def unlock_account(request, user_id):
 	try:
+		identity_service = get_identity_service()
 		user = get_object_or_404(User, id=user_id)
-		timeout = settings.IDENTITY_SERVICE.get('timeout', 3)
-		result = requests.post(urljoin(settings.IDENTITY_SERVICE['url'], '/unlock_account/'), {'username': user.username, 'domain': user.domain}, timeout=timeout)
+		timeout = identity_service.get('timeout', 3)
+		result = requests.post(urljoin(identity_service['url'], '/unlock_account/'), {'username': user.username, 'domain': user.domain}, timeout=timeout)
 		if result.status_code == HTTPStatus.OK:
 			dictionary = {
 				'title': 'Account unlocked',
@@ -318,3 +341,7 @@ def user_preferences(request):
 		'user_preferences': user.preferences,
 	}
 	return render(request, 'users/preferences.html', dictionary)
+
+
+def get_identity_service():
+	return getattr(settings, 'IDENTITY_SERVICE', {})
\ No newline at end of file
